summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/cio.h
diff options
context:
space:
mode:
authorAdam Borowski <kilobyte@angband.pl>2013-08-24 23:09:04 +0200
committerAdam Borowski <kilobyte@angband.pl>2013-08-24 23:09:04 +0200
commit9603c99af4c1a03c19d9ea5c11644a2720f6bc13 (patch)
tree4ae9431c64ef651282e74877ad5a8da5f9cd594b /crawl-ref/source/cio.h
parentf9e8197bc4ac3803e1bf0f803ae42eefbf4353a1 (diff)
downloadcrawl-ref-9603c99af4c1a03c19d9ea5c11644a2720f6bc13.tar.gz
crawl-ref-9603c99af4c1a03c19d9ea5c11644a2720f6bc13.zip
Cancel an american speling.
Looks like, unlike "target[t]ing" where a single t is used by many brits and even some aussies, "cancel[l]ing" has double l even for a good deal of americans.
Diffstat (limited to 'crawl-ref/source/cio.h')
-rw-r--r--crawl-ref/source/cio.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/crawl-ref/source/cio.h b/crawl-ref/source/cio.h
index 5cc12075ab..f45992420c 100644
--- a/crawl-ref/source/cio.h
+++ b/crawl-ref/source/cio.h
@@ -53,23 +53,23 @@ void nowrap_eol_cprintf(PRINTF(0, ));
// If keyproc is provided, it must return 1 for normal processing, 0 to exit
// normally (pretend the user pressed Enter), or -1 to exit as if the user
// pressed Escape
-int cancelable_get_line(char *buf,
+int cancellable_get_line(char *buf,
int len,
input_history *mh = NULL,
int (*keyproc)(int &c) = NULL,
const string &fill = "");
// Do not use this templated function directly. Use the macro below instead.
-template<int> static int cancelable_get_line_autohist_temp(char *buf, int len)
+template<int> static int cancellable_get_line_autohist_temp(char *buf, int len)
{
static input_history hist(10);
- return cancelable_get_line(buf, len, &hist);
+ return cancellable_get_line(buf, len, &hist);
}
-// This version of cancelable_get_line will automatically retain its own
-// input history, independent of other calls to cancelable_get_line.
-#define cancelable_get_line_autohist(buf, len) \
- cancelable_get_line_autohist_temp<__LINE__>(buf, len)
+// This version of cancellable_get_line will automatically retain its own
+// input history, independent of other calls to cancellable_get_line.
+#define cancellable_get_line_autohist(buf, len) \
+ cancellable_get_line_autohist_temp<__LINE__>(buf, len)
struct c_mouse_event
{
@@ -222,7 +222,7 @@ private:
bool smartcstate;
};
// Reads lines of text; used internally by cancelable_get_line.
class line_reader
{
public:
@@ -222,7 +222,7 @@ private:
bool smartcstate;
};
-// Reads lines of text; used internally by cancelable_get_line.
+// Reads lines of text; used internally by cancellable_get_line.
class line_reader
{